@@ -20,22 +20,18 @@ class CallCenterVoiceMeta(mongoengine.DynamicEmbeddedDocument):
     def get_meta_list_from_asr_result(
         cls, asr_result: str
     ) -> List["CallCenterVoiceMeta"]:
-        try:
-            data = json.loads(asr_result)
-            result = []
-            for i in data:
-                result.append(
-                    cls(
-                        start_time=i["Begin"],
-                        end_time=i["End"],
-                        text=i["Words"],
-                        from_role=i["Role"],
-                    )
+        data = json.loads(asr_result)
+        result = []
+        for i in data:
+            result.append(
+                cls(
+                    start_time=i["Begin"],
+                    end_time=i["End"],
+                    text=i["Words"],
+                    from_role=i["Role"],
                 )
-                return result
-        except Exception as e:
-            logging.exception(f"call center parser error. {e}")
-            return []
+            )
+        return result
 
 
 class CallCenter(mongoengine.DynamicDocument, MultiDatabaseMixin, MongoCanalKafkaMixin):
