@@ -1,3 +1,5 @@
+import datetime
+
 import mongoengine
 
 from insnail_ai_tools.mongodb.mixin import MultiDatabaseMixin, StrChoicesMixin
@@ -109,3 +111,33 @@ class WecomUserExtraInfo(mongoengine.DynamicDocument, MultiDatabaseMixin):
         "indexes": ["#user_name", "#phone_number"],
         "abstract": True,
     }
+
+
+class IllegalMeta(mongoengine.EmbeddedDocument):
+    illegal_type = mongoengine.StringField(verbose_name="违规类型")
+    illegal_level = mongoengine.IntField(verbose_name="违规等级")
+    illegal_words = mongoengine.ListField(mongoengine.StringField())
+
+    def __str__(self):
+        return f"{self.illegal_type}-{self.illegal_type}-{self.illegal_words}"
+
+
+class MessageCheckResult(mongoengine.DynamicDocument, MultiDatabaseMixin):
+    msg_id = mongoengine.StringField(verbose_name="对于消息的ID")
+    msg_mode = mongoengine.StringField(verbose_name="消息类型")
+    msg_time = mongoengine.DateTimeField(verbose_name="消息时间")
+
+    illegal_list = mongoengine.ListField(IllegalMeta)
+
+    create_time = mongoengine.DateTimeField(
+        verbose_name="创建时间", default=datetime.datetime.now
+    )
+
+    meta = {
+        "collection": "message_check_result",
+        "indexes": ["#msg_id", "#msg_mode", "msg_time"],
+        "abstract": True,
+    }
+
+    def __str__(self):
+        return f"{self.msg_id}-{self.msg_mode}-{self.illegal_list}"
